==> tekton-model-triggers-v1alpha1-6.6.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerTemplateFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TriggerTemplateFluentImpl<A extends TriggerTemplateFluent<A>> extends BaseFluent<A> implements TriggerTemplateFluent<A>{
  public TriggerTemplateFluentImpl() {
  }
  public TriggerTemplateFluentImpl(TriggerTemplate instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private TriggerTemplateSpecBuilder spec;
  private TriggerTemplateStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public TriggerTemplateFluent.MetadataNested<A> withNewMetadata() {
    return new TriggerTemplateFluentImpl.MetadataNestedImpl();
  }
  public TriggerTemplateFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new TriggerTemplateFluentImpl.MetadataNestedImpl(item);
  }
  public TriggerTemplateFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public TriggerTemplateFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public TriggerTemplateFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerTemplateSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public TriggerTemplateSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(TriggerTemplateSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new TriggerTemplateSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public TriggerTemplateFluent.SpecNested<A> withNewSpec() {
    return new TriggerTemplateFluentImpl.SpecNestedImpl();
  }
  public TriggerTemplateFluent.SpecNested<A> withNewSpecLike(TriggerTemplateSpec item) {
    return new TriggerTemplateFluentImpl.SpecNestedImpl(item);
  }
  public TriggerTemplateFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public TriggerTemplateFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new TriggerTemplateSpecBuilder().build());
  }
  public TriggerTemplateFluent.SpecNested<A> editOrNewSpecLike(TriggerTemplateSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerTemplateStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public TriggerTemplateStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(TriggerTemplateStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new TriggerTemplateStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public TriggerTemplateFluent.StatusNested<A> withNewStatus() {
    return new TriggerTemplateFluentImpl.StatusNestedImpl();
  }
  public TriggerTemplateFluent.StatusNested<A> withNewStatusLike(TriggerTemplateStatus item) {
    return new TriggerTemplateFluentImpl.StatusNestedImpl(item);
  }
  public TriggerTemplateFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public TriggerTemplateFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new TriggerTemplateStatusBuilder().build());
  }
  public TriggerTemplateFluent.StatusNested<A> editOrNewStatusLike(TriggerTemplateStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TriggerTemplateFluentImpl that = (TriggerTemplateFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<TriggerTemplateFluent.MetadataNested<N>> implements TriggerTemplateFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) TriggerTemplateFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends TriggerTemplateSpecFluentImpl<TriggerTemplateFluent.SpecNested<N>> implements TriggerTemplateFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(TriggerTemplateSpec item) {
      this.builder = new TriggerTemplateSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new TriggerTemplateSpecBuilder(this);
    }
    TriggerTemplateSpecBuilder builder;
    public N and() {
      return (N) TriggerTemplateFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends TriggerTemplateStatusFluentImpl<TriggerTemplateFluent.StatusNested<N>> implements TriggerTemplateFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(TriggerTemplateStatus item) {
      this.builder = new TriggerTemplateStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new TriggerTemplateStatusBuilder(this);
    }
    TriggerTemplateStatusBuilder builder;
    public N and() {
      return (N) TriggerTemplateFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerTemplateFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TriggerTemplateFluentImpl<A extends TriggerTemplateFluent<A>> extends BaseFluent<A> implements TriggerTemplateFluent<A>{
  public TriggerTemplateFluentImpl() {
  }
  public TriggerTemplateFluentImpl(TriggerTemplate instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private TriggerTemplateSpecBuilder spec;
  private TriggerTemplateStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public TriggerTemplateFluentImpl.MetadataNested<A> withNewMetadata() {
    return new TriggerTemplateFluentImpl.MetadataNestedImpl();
  }
  public TriggerTemplateFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new TriggerTemplateFluentImpl.MetadataNestedImpl(item);
  }
  public TriggerTemplateFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public TriggerTemplateFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public TriggerTemplateFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerTemplateSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public TriggerTemplateSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(TriggerTemplateSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new TriggerTemplateSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public TriggerTemplateFluentImpl.SpecNested<A> withNewSpec() {
    return new TriggerTemplateFluentImpl.SpecNestedImpl();
  }
  public TriggerTemplateFluentImpl.SpecNested<A> withNewSpecLike(TriggerTemplateSpec item) {
    return new TriggerTemplateFluentImpl.SpecNestedImpl(item);
  }
  public TriggerTemplateFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public TriggerTemplateFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new TriggerTemplateSpecBuilder().build());
  }
  public TriggerTemplateFluentImpl.SpecNested<A> editOrNewSpecLike(TriggerTemplateSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerTemplateStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public TriggerTemplateStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(TriggerTemplateStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new TriggerTemplateStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public TriggerTemplateFluentImpl.StatusNested<A> withNewStatus() {
    return new TriggerTemplateFluentImpl.StatusNestedImpl();
  }
  public TriggerTemplateFluentImpl.StatusNested<A> withNewStatusLike(TriggerTemplateStatus item) {
    return new TriggerTemplateFluentImpl.StatusNestedImpl(item);
  }
  public TriggerTemplateFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public TriggerTemplateFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new TriggerTemplateStatusBuilder().build());
  }
  public TriggerTemplateFluentImpl.StatusNested<A> editOrNewStatusLike(TriggerTemplateStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TriggerTemplateFluentImpl that = (TriggerTemplateFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<TriggerTemplateFluentImpl.MetadataNested<N>> implements TriggerTemplateFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) TriggerTemplateFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends TriggerTemplateSpecFluentImpl<TriggerTemplateFluentImpl.SpecNested<N>> implements TriggerTemplateFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(TriggerTemplateSpec item) {
      this.builder = new TriggerTemplateSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new TriggerTemplateSpecBuilder(this);
    }
    TriggerTemplateSpecBuilder builder;
    public N and() {
      return (N) TriggerTemplateFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends TriggerTemplateStatusFluentImpl<TriggerTemplateFluentImpl.StatusNested<N>> implements TriggerTemplateFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(TriggerTemplateStatus item) {
      this.builder = new TriggerTemplateStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new TriggerTemplateStatusBuilder(this);
    }
    TriggerTemplateStatusBuilder builder;
    public N and() {
      return (N) TriggerTemplateFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
